summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirstatapp.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit44af2b7aa26c61f2f059acc7a9726319cacaabcf (patch)
tree09c93f4a6fdef07c083e731d9f327850e83a6bf5 /kdirstat/kdirstatapp.h
parentb8e1a56a901671dbd336c9bfd129dfb72a0cc41f (diff)
downloadkdirstat-44af2b7aa26c61f2f059acc7a9726319cacaabcf.tar.gz
kdirstat-44af2b7aa26c61f2f059acc7a9726319cacaabcf.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kdirstatapp.h')
-rw-r--r--kdirstat/kdirstatapp.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdirstat/kdirstatapp.h b/kdirstat/kdirstatapp.h
index ea883b7..51e230a 100644
--- a/kdirstat/kdirstatapp.h
+++ b/kdirstat/kdirstatapp.h
@@ -79,7 +79,7 @@ public:
* Construtor of KDirStatApp, calls all init functions to create the
* application.
**/
- KDirStatApp( TQWidget* tqparent=0, const char* name=0 );
+ KDirStatApp( TQWidget* parent=0, const char* name=0 );
/**
* Destructor.
@@ -185,7 +185,7 @@ public slots:
void treemapZoomOut();
/**
* Select the tqparent of the currently selected treemap tile.
**/
void treemapSelectParent();
@@ -185,7 +185,7 @@ public slots:
void treemapZoomOut();
/**
- * Select the tqparent of the currently selected treemap tile.
+ * Select the parent of the currently selected treemap tile.
**/
void treemapSelectParent();